/*    
	kimproxy.h
	
	IM service library for KDE
	
	Copyright (c) 2004 Will Stephenson   <lists@stevello.free-online.co.uk>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef KIMPROXY_H
#define KIMPROXY_H

#include <qstringlist.h>


#define IM_SERVICE_TYPE "DCOP/InstantMessenger"
#define IM_CLIENT_PREFERENCES_FILE "default_components"
#define IM_CLIENT_PREFERENCES_SECTION "InstantMessenger"
#define IM_CLIENT_PREFERENCES_ENTRY "imClient"

#include <kimproxyiface.h>

class DCOPClient;
class KIMIface_stub;
class KURL;

class KIMProxy : public QObject, virtual public KIMProxyIface
{
	Q_OBJECT

	public:
		/**
		 * Construct an instance of the proxy library
		 * @param your app's DCOP client 
		 */
		KIMProxy( DCOPClient *);
		~KIMProxy();

		/**
		 * Get the proxy ready to connect
		 * Discover the preferred IM client and connect to it
		 */
		bool initialize();

		/**
		 * Obtain a list of IM-contactable entries in the KDE 
		 * address book.
		 * @return a list of KABC uids.
		 */
		QStringList imAddresseeUids();

		/**
		 * Obtain the IM status as a i18ned string for the specified addressee
		 * @param uid the KABC uid you want the status for.
		 */

		int statusNumeric( const QString& uid );
		/**
		 * Obtain the IM status as a number (see KIMIface) for the specified addressee
		 * @param uid the KABC uid you want the status for.
		 */
		QString statusString( const QString& uid );

		/**
		 * Obtain the icon representing IM status for the specified addressee
		 * @param uid the KABC uid you want the status for.
		 */
		QPixmap statusIcon( const QString& uid );

		/**
		 * Start a chat session with the specified addressee
		 * @param uid the KABC uid you want to chat with.
		 */
		void chatContactById( const QString& uid );

		/**
		 * Send a single message to the specified addressee
		 * Any response will be handled by the IM client as a normal 
		 * conversation.
		 * @param uid the KABC uid you want to chat with.
		 * @param message the message to send them.
		 */
		void messageContactById( const QString& uid, const QString& uid );

		/**
		 * Send the file to the contact
		 */
		void sendFileToId(const QString &metaContactId, const KURL &sourceURL, const QString &altFileName = QString::null, uint fileSize = 0);

		/**
		 * Just exists to let the idl compiler make the DCOP signal for this
		 */
		void contactStatusChanged( QString uid );
		public slots:
			void unregisteredFromDCOP( const QCString& appId );
signals:
		void sigContactStatusChanged( QString uid );
	protected:
		KIMIface_stub *m_im_client_stub;
		DCOPClient *m_dc;
};

#endif

